# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: knowledge.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'knowledge.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fknowledge.proto\x12\x05\x66onts\"!\n\x0eKnowledgeProto\x12\x0f\n\x07modules\x18\x01 \x03(\t\"N\n\x0bModuleProto\x12\x0f\n\x07\x61lt_ids\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x65xcerpt\x18\x03 \x01(\t\x12\x0f\n\x07lessons\x18\x04 \x03(\t\"+\n\nTopicProto\x12\x0f\n\x07\x61lt_ids\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd2\x01\n\x0bLessonProto\x12\x0f\n\x07\x61lt_ids\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61uthors\x18\x03 \x03(\t\x12\x11\n\treviewers\x18\x04 \x03(\t\x12\x0e\n\x06topics\x18\x05 \x03(\t\x12\x14\n\x0cprev_lessons\x18\x06 \x03(\t\x12\x14\n\x0cnext_lessons\x18\x07 \x03(\t\x12\x15\n\rrelated_terms\x18\x08 \x03(\t\x12\x0f\n\x07\x65xcerpt\x18\t \x01(\t\x12\x1c\n\x14related_content_urls\x18\n \x03(\t\"r\n\tTermProto\x12\x0f\n\x07\x61lt_ids\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x65xcerpt\x18\x03 \x01(\t\x12\x17\n\x0frelated_lessons\x18\x04 \x03(\t\x12\x1c\n\x14related_content_urls\x18\x05 \x03(\t\"\x8d\x01\n\x11\x43ontributorsProto\x12?\n\x0c\x63ontributors\x18\x01 \x03(\x0b\x32).fonts.ContributorsProto.ContributorProto\x1a\x37\n\x10\x43ontributorProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rpersonal_site\x18\x02 \x01(\tB#\n\x16\x63om.google.fonts.protoB\tKnowledge')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'knowledge_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.google.fonts.protoB\tKnowledge'
  _globals['_KNOWLEDGEPROTO']._serialized_start=26
  _globals['_KNOWLEDGEPROTO']._serialized_end=59
  _globals['_MODULEPROTO']._serialized_start=61
  _globals['_MODULEPROTO']._serialized_end=139
  _globals['_TOPICPROTO']._serialized_start=141
  _globals['_TOPICPROTO']._serialized_end=184
  _globals['_LESSONPROTO']._serialized_start=187
  _globals['_LESSONPROTO']._serialized_end=397
  _globals['_TERMPROTO']._serialized_start=399
  _globals['_TERMPROTO']._serialized_end=513
  _globals['_CONTRIBUTORSPROTO']._serialized_start=516
  _globals['_CONTRIBUTORSPROTO']._serialized_end=657
  _globals['_CONTRIBUTORSPROTO_CONTRIBUTORPROTO']._serialized_start=602
  _globals['_CONTRIBUTORSPROTO_CONTRIBUTORPROTO']._serialized_end=657
# @@protoc_insertion_point(module_scope)
